@@ -4,7 +4,12 @@ import logging
 import sys
 from ucloud import version
 from ucloud.core.client._cfg import Config
-from ucloud.core.transport import Transport, RequestsTransport, Request
+from ucloud.core.transport import (
+    Transport,
+    RequestsTransport,
+    Request,
+    SSLOption,
+)
 from ucloud.core.typesystem import encoder
 from ucloud.core.utils import log
 from ucloud.core.utils.middleware import Middleware
@@ -39,6 +44,8 @@ class Client(object):
             try:
                 return self._send(action, args or {}, **options)
             except exc.UCloudException as e:
+                for handler in self.middleware.exception_handlers:
+                    handler(e)
                 if e.retryable and retries != max_retries:
                     logging.info(
                         "Retrying {action}: {args}".format(
@@ -49,6 +56,8 @@ class Client(object):
                     continue
                 raise e
             except Exception as e:
+                for handler in self.middleware.exception_handlers:
+                    handler(e)
                 raise e
 
     @property
@@ -77,7 +86,15 @@ class Client(object):
         max_retries = options.get("max_retries") or self.config.max_retries
         timeout = options.get("timeout") or self.config.timeout
         resp = self.transport.send(
-            req, timeout=timeout, max_retries=max_retries
+            req,
+            ssl_option=SSLOption(
+                self.config.ssl_verify,
+                self.config.ssl_cacert,
+                self.config.ssl_cert,
+                self.config.ssl_key,
+            ),
+            timeout=timeout,
+            max_retries=max_retries,
         ).json()
         for handler in self.middleware.response_handlers:
             resp = handler(resp)
@@ -116,4 +133,6 @@ class Client(object):
         return user_agent
 
     def __repr__(self):
-        return '<{}("{}")>'.format(self.__class__.__name__, self.config.region)
+        return '<{}(region="{}")>'.format(
+            self.__class__.__name__, self.config.region
+        )
